@@ -12,7 +12,7 @@
 #              style files of BibTeX 0.99.
 # CREATED    : 1997/09/21, Greg Ward
 # MODIFIED   : 
-# VERSION    : $Id: Bib.pm 8423 2010-02-13 20:40:27Z ambs $
+# VERSION    : $Id$
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -27,7 +27,7 @@ Text::BibTeX::Bib - defines the "Bib" database structure
 
 =head1 SYNOPSIS
 
-   $bibfile = new Text::BibTeX::File $filename;
+   $bibfile = Text::BibTeX::File $filename->new;
    $bibfile->set_structure ('Bib',
                             # Default option values:
                             sortby => 'name',
@@ -45,11 +45,11 @@ Text::BibTeX::Bib - defines the "Bib" database structure
    $bibfile->set_option (labels => 'alpha');   # not implemented yet!
 
    # parse entry from $bibfile and automatically make it a BibEntry
-   $entry = new Text::BibTeX::Entry $bibfile;
+   $entry = Text::BibTeX::Entry->new($bibfile);
 
    # or get an entry from somewhere else which is hard-coded to be
    # a BibEntry
-   $entry = new Text::BibTeX::BibEntry ...;
+   $entry = Text::BibTeX::BibEntry->new(...);
 
    $sortkey = $entry->sort_key;
    @blocks = $entry->format;
@@ -109,8 +109,9 @@ BibTeX 0.99-style bibliography databases.)
 
 package Text::BibTeX::BibStructure;
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 @ISA = qw(Text::BibTeX::Structure);
+$VERSION = '0.76';
 
 =head1 STRUCTURE OPTIONS
 
@@ -447,33 +448,15 @@ L<Text::BibTeX::BibFormat> for details on these two methods.
 
 package Text::BibTeX::BibEntry;
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
+
+$VERSION = '0.76';
 
 use Text::BibTeX::BibSort;
 use Text::BibTeX::BibFormat;
 
 @ISA = qw(Text::BibTeX::BibSort Text::BibTeX::BibFormat);
-
-# Pre-define the "month name" macros for compatibility with BibTeX.
-# This ignores all sorts of issues, like internationalization and
-# abbreviation.  
-my %month_names = 
-   ('jan' => 'January',
-    'feb' => 'February',
-    'mar' => 'March',
-    'apr' => 'April',
-    'may' => 'May',
-    'jun' => 'June',
-    'jul' => 'July',
-    'aug' => 'August',
-    'sep' => 'September',
-    'oct' => 'October',
-    'nov' => 'November',
-    'dec' => 'December');
-
-my ($macro, $expansion);
-Text::BibTeX::add_macro_text ($macro, $expansion)
-   while (($macro, $expansion) = each %month_names);    
+ 
 
 1;
 
